------------------
Gaussian processes
------------------

This module provides a collection of tools
that are useful when performing Gaussian
process regression.

Numpy
~~~~~

.. currentmodule:: africanus.gps

.. autosummary::
    abs_diff
    exponential_squared

.. autofunction:: abs_diff
.. autofunction:: exponential_squared